'use strict';

const process = require('node:process');
const kolorist = require('kolorist');
const yargs = require('yargs');
const helpers = require('yargs/helpers');
const node = require('../node.cjs');
require('node:path');
require('node:module');
require('fs-extra');
require('vite');
require('../shared/vite-ssg.e6991406.cjs');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e.default : e; }

const process__default = /*#__PURE__*/_interopDefaultCompat(process);
const yargs__default = /*#__PURE__*/_interopDefaultCompat(yargs);

yargs__default(helpers.hideBin(process__default.argv)).scriptName("vite-ssg").usage("$0 [args]").command(
  "build",
  "Build SSG",
  (args) => args.option("script", {
    choices: ["sync", "async", "defer", "async defer"],
    describe: "Rewrites script loading timing"
  }).option("mock", {
    type: "boolean",
    describe: "Mock browser globals (window, document, etc.) for SSG"
  }).option("config", {
    alias: "c",
    type: "string",
    describe: "The vite config file to use"
  }).option("base", {
    alias: "b",
    type: "string",
    describe: "The base path to render"
  }),
  async (args) => {
    const { config: configFile = void 0, ...ssgOptions } = args;
    await node.build(ssgOptions, { configFile });
  }
).fail((msg, err, yargs2) => {
  console.error(`
${kolorist.gray("[vite-ssg]")} ${kolorist.bold(kolorist.red("An internal error occurred."))}`);
  console.error(`${kolorist.gray("[vite-ssg]")} ${kolorist.reset(`Please report an issue, if none already exists: ${kolorist.underline("https://github.com/antfu/vite-ssg/issues")}`)}`);
  yargs2.exit(1, err);
}).showHelpOnFail(false).help().argv;
//# sourceMappingURL=cli.cjs.map
