import process from 'node:process';
import { gray, bold, red, reset, underline } from 'kolorist';
import yargs from 'yargs';
import { hideBin } from 'yargs/helpers';
import { build } from '../node.mjs';
import 'node:path';
import 'node:module';
import 'fs-extra';
import 'vite';
import '../shared/vite-ssg.a009fbf1.mjs';

yargs(hideBin(process.argv)).scriptName("vite-ssg").usage("$0 [args]").command(
  "build",
  "Build SSG",
  (args) => args.option("script", {
    choices: ["sync", "async", "defer", "async defer"],
    describe: "Rewrites script loading timing"
  }).option("mock", {
    type: "boolean",
    describe: "Mock browser globals (window, document, etc.) for SSG"
  }).option("config", {
    alias: "c",
    type: "string",
    describe: "The vite config file to use"
  }).option("base", {
    alias: "b",
    type: "string",
    describe: "The base path to render"
  }),
  async (args) => {
    const { config: configFile = void 0, ...ssgOptions } = args;
    await build(ssgOptions, { configFile });
  }
).fail((msg, err, yargs2) => {
  console.error(`
${gray("[vite-ssg]")} ${bold(red("An internal error occurred."))}`);
  console.error(`${gray("[vite-ssg]")} ${reset(`Please report an issue, if none already exists: ${underline("https://github.com/antfu/vite-ssg/issues")}`)}`);
  yargs2.exit(1, err);
}).showHelpOnFail(false).help().argv;
//# sourceMappingURL=cli.mjs.map
